Coverage for /home/masasin/desktop/pyrosbag/pyrosbag/__init__.py: 100%

# Coverage for /home/masasin/desktop/pyrosbag/pyrosbag/__init__.py : 100%

## 4 statements 4 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 | # -*- coding: utf-8 -*- """ Note that, in order to access the data within the bag file, the ``rosbag_python`` package is extremely convenient. It is available on PyPI. """ __author__ = """Jean Nassar""" __email__ = 'jeannassar5@gmail.com' __version__ = '0.1.0'